@@ -1,4 +1,5 @@
 # frozen_string_literal: true
+
 module Browser
   class AcceptLanguage
     def self.languages
@@ -32,7 +33,10 @@ module Browser
     end
 
     def code
-      @code ||= part[/\A([^-;]+)/, 1]
+      @code ||= begin
+        code = part[/\A([^-;]+)/, 1]
+        code.downcase if code
+      end
     end
 
     def region
@@ -43,14 +47,20 @@ module Browser
     end
 
     def quality
-      @quality ||= Float(quality_value || 1.0)
+      @quality ||= begin
+        Float(quality_value || 1.0)
+      rescue ArgumentError
+        0.1
+      end
     end
 
     private
 
     def quality_value
       qvalue = part[/;q=([\d.]+)/, 1]
-      qvalue =~ /\A0\.0?\z/ ? "0.0" : qvalue
+      qvalue = qvalue =~ /\A0\.0?\z/ ? "0.0" : qvalue
+      qvalue = qvalue.gsub(/\.+/, ".") if qvalue
+      qvalue
     end
   end
 end
