@@ -1,10 +1,11 @@
 # frozen_string_literal: true
+
 module Browser
   class Generic < Base
     NAMES = {
       "QuickTime" => "QuickTime",
       "CoreMedia" => "Apple CoreMedia"
-    }
+    }.freeze
 
     def id
       :generic
