@@ -1,4 +1,6 @@
-class Browser
+# frozen_string_literal: true
+
+module Browser
   module Meta
     class GenericBrowser < Base
       def meta
