@@ -1,6 +1,8 @@
+# frozen_string_literal: true
+
 require "browser/middleware/context/url_methods"
 
-class Browser
+module Browser
   class Middleware
     class Context
       module Additions
