@@ -1,4 +1,5 @@
 # frozen_string_literal: true
+
 module Browser
   class QQ < Base
     def id
@@ -11,6 +12,8 @@ module Browser
 
     def full_version
       ua[%r[(?:Mobile MQQBrowser)/([\d.]+)]i, 1] ||
+        ua[%r[(?:QQBrowserLite)/([\d.]+)]i, 1] ||
+        ua[%r[(?:QQBrowser)/([\d.]+)]i, 1] ||
         ua[%r[(?:QQ)/([\d.]+)]i, 1] ||
         "0.0"
     end
