@@ -1,4 +1,5 @@
 # frozen_string_literal: true
+
 require "rails/railtie"
 require "browser/action_controller"
 require "browser/middleware/context/additions"
@@ -8,9 +9,13 @@ module Browser
     config.browser = ActiveSupport::OrderedOptions.new
 
     initializer "browser" do
-      ::ActionController::Base.send :include, Browser::ActionController
-      Browser::Middleware::Context.send :include,
-                                        Browser::Middleware::Context::Additions
+      ActiveSupport.on_load(:action_controller) do
+        ::ActionController::Base.send :include, Browser::ActionController
+        Browser::Middleware::Context.send(
+          :include,
+          Browser::Middleware::Context::Additions
+        )
+      end
     end
   end
 end
