@@ -1,6 +1,7 @@
 # frozen_string_literal: true
-require "codeclimate-test-reporter"
-CodeClimate::TestReporter.start
+
+require "simplecov"
+SimpleCov.start
 
 ENV["BUNDLE_GEMFILE"] ||= File.expand_path("../../Gemfile", __FILE__)
 require "bundler/setup"
