@@ -1,4 +1,5 @@
 # frozen_string_literal: true
+
 require "test_helper"
 
 class OperaTest < Minitest::Test
@@ -30,6 +31,11 @@ class OperaTest < Minitest::Test
     assert browser.opera_mini?
   end
 
+  test "detects opera mini version by range" do
+    browser = Browser.new(Browser["OPERA_MINI"])
+    assert browser.opera_mini?(%w[>=11 <12])
+  end
+
   test "detects opera mobi" do
     browser = Browser.new(Browser["OPERA_MOBI"])
     assert browser.opera?
@@ -39,4 +45,9 @@ class OperaTest < Minitest::Test
     browser = Browser.new(Browser["OPERA_ANDROID"])
     assert browser.platform.android?
   end
+
+  test "detects version by range" do
+    browser = Browser.new(Browser["OPERA"])
+    assert browser.opera?(%w[>=11 <12])
+  end
 end
